/***************************************************************************
                          mylistview.cpp  -  description
                             -------------------
    begin                : Mon Jun 18 2001
    copyright            : (C) 2001 by Rdiger Knrig
    email                : ruediger@knoerig.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qstringlist.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qtooltip.h>
#include <qmessagebox.h>
#include "mylistview.h"


MyListView::MyListView(QStringList &items,QWidget *parent, const char *name ) : QWidget(parent,name)
{
	mainlayout = new QGridLayout(this,2,2,2,5,"mainlayout");
	buttonlayout = new QVBoxLayout(5,"buttonlayout");
	propertylayout = new QHBoxLayout(5,"propertylayout");
	mainlayout->addLayout(buttonlayout,0,1);
	mainlayout->addMultiCellLayout(propertylayout,1,1,0,1,Qt::AlignLeft);
	
	listview = new QListBox(this,"listview");
	listview->insertStringList(items);
	listview->setSizePolicy(QSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred));
	QToolTip::add(listview,"left mouse button selects");
	mainlayout->addWidget(listview,0,0);

	newitembutton = new QPushButton("New Item",this);
	appenditembutton = new QPushButton("Append Item",this);
	deleteitembutton = new QPushButton("Delete Item",this);
	//deleteitembutton->setAccel(Key_Backspace);
	//QToolTip::add(deleteitembutton,"you can use backspace also!");
	
	moveupbutton = new QPushButton("Up",this);
	//moveupbutton->setAccel(Key_Up);
	QToolTip::add(moveupbutton,"moves item up");
	
	movedownbutton = new QPushButton("Down",this);
	//movedownbutton->setAccel(Key_Down);
	QToolTip::add(movedownbutton,"moves item down");
	
	buttonlayout->addWidget(newitembutton);
	buttonlayout->addWidget(appenditembutton);
	buttonlayout->addWidget(deleteitembutton);
	buttonlayout->addWidget(moveupbutton);
	buttonlayout->addWidget(movedownbutton);
	
	propertylayout->addWidget(new QLabel("property: ",this));
	entry = new QLineEdit(this,"entry");
	QToolTip::add(entry,"press return to accept change or insert!");
	entry->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::Fixed));
	propertylayout->addWidget(entry);
	
	QObject::connect(listview,SIGNAL(clicked(QListBoxItem *)),this,SLOT(slotSelectItem(QListBoxItem *)));
	QObject::connect(listview,SIGNAL(contentsMoving(int,int)),this,SLOT(slotMoveContent(int,int)));
	QObject::connect(newitembutton,SIGNAL(clicked()),this,SLOT(slotInsertItem()));
	QObject::connect(appenditembutton,SIGNAL(clicked()),this,SLOT(slotAppendItem()));
	QObject::connect(deleteitembutton,SIGNAL(clicked()),this,SLOT(slotDeleteItem()));
	QObject::connect(moveupbutton,SIGNAL(clicked()),this,SLOT(slotMoveUpItem()));
	QObject::connect(movedownbutton,SIGNAL(clicked()),this,SLOT(slotMoveDownItem()));	
	QObject::connect(entry,SIGNAL(returnPressed()),this,SLOT(slotAcceptItem()));


}

MyListView::~MyListView()
{

}

/** activated when return is pressed in entry */
void MyListView::slotAcceptItem()
{
	if(entry->text().isEmpty())
		{
			QMessageBox::information(this,"a2psfrontend setup","Text entry is empty!");
			entry->setFocus();
		}
		else
		{
			int index;
			if((index = listview->currentItem()) < 0)
			{
				// insert Item at last position
				listview->insertItem(entry->text());
			}
			else
			{
				// change item
				listview->changeItem(entry->text(),index);
			}
		}
}

/** appends an item at the end of the list */
void MyListView::slotAppendItem()
{
		if(entry->text().isEmpty())
		{
			QMessageBox::information(this,"a2psfrontend setup","Text entry is empty!");
			entry->setFocus();
		}
		else
		{
			listview->insertItem(entry->text(),-1);
		}
}

/** inserts an item */
void MyListView::slotInsertItem()
{
		if(entry->text().isEmpty())
		{
			QMessageBox::information(this,"a2psfrontend setup","Text entry is empty!");
			entry->setFocus();
		}
		else
		{
			listview->insertItem(entry->text(),listview->currentItem());
		}
}

/** moves an item from index form to index to */
void MyListView::slotMoveContent(int from, int to)
{
	QListBoxItem *item = listview->item(from);
	listview->takeItem(item);
	listview->insertItem(item,to);
	listview->setCurrentItem(to);
}
/** 
	* returns a QStringList with the listbox items
	* @return QStringList with the listbox items
 	*/
QStringList MyListView::getItemList()
{
	QStringList itemlist;
	
	for(QListBoxItem *p=listview->firstItem(); p != 0; p = p->next()) itemlist << p->text();
	return(itemlist);
}
