/***************************************************************************
                          mysetupdialog.cpp  -  description
                             -------------------
    begin                : Thu Jun 14 2001
    copyright            : (C) 2001 by Rdiger Knrig
    email                : ruediger@knoerig.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qpushbutton.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qfile.h>
#include <qdatastream.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qmessagebox.h>
#include "mysetupdialog.h"
#include "mylistview.h"
#include "myfilepicker.h"

MySetupDialog::MySetupDialog(QString configfilename, QString *a2psexec, QString *gvexec,\
 QStringList *codecs,QStringList *printers,QWidget *parent, const char *name ) : QDialog(parent,name,true)
{
	output = new QFile(configfilename);
	downstream = new QDataStream(output);
	
	a2ps = a2psexec;
	gv = gvexec;
	this->codecs = codecs;
	this->printers = printers;
	
	setCaption("a2psfrontend setup");	
	pickerbox = new QGroupBox(1,Qt::Horizontal,"command selection",this);
	commandpicker = new MyFilePicker("a2ps command\t\t\t",*a2psexec,pickerbox);
	viewerpicker = new MyFilePicker("postscript viewer command\t",*gvexec,pickerbox);
	mainlayout = new QVBoxLayout(this,5,-1,"mainlayout");
	mainlayout->addWidget(pickerbox);
	
	listviewbox = new QGroupBox(2,Qt::Horizontal,"predefined choices",this);
	
	new QLabel("coding systems",listviewbox);
	new QLabel("printers",listviewbox);
	codeclist = new MyListView(*codecs,listviewbox,"codeclist");
	printerlist = new MyListView(*printers,listviewbox,"printerlist");
	
	mainlayout->addWidget(listviewbox);
	
	okbutton = new QPushButton("&Ok",this);
	cancelbutton = new QPushButton("Cancel",this);
	cancelbutton->setAccel(Key_Escape);
	buttonlayout = new QHBoxLayout(mainlayout,5,"buttonlayout");
	buttonlayout->addWidget(cancelbutton,0,Qt::AlignLeft);
	buttonlayout->addWidget(okbutton,0,Qt::AlignRight);	
	
	QObject::connect(cancelbutton,SIGNAL(clicked()),this,SLOT(reject()));
	QObject::connect(okbutton,SIGNAL(clicked()),this,SLOT(slotAccept()));
}

MySetupDialog::~MySetupDialog()
{	
	if(!output) output->close();
}

/**
	* user accepted settings, so we change
	* the attributes and the config file
	*/
void MySetupDialog::slotAccept()
{
	if(!output->open( IO_WriteOnly )) QMessageBox::information(this, "a2psfrontend setup","Could not open for writing!");
	
	QString tempstr;
	QStringList tempstrlist;
	
	tempstr = commandpicker->getFileName();
	*downstream << (*a2ps = ( (tempstr.isEmpty()) ? QString("a2ps ") : tempstr) );
	
	tempstr = viewerpicker->getFileName();
	*downstream << (*gv = ( (tempstr.isEmpty()) ? QString("gv ") : tempstr) );	
	
	tempstrlist = codeclist->getItemList();
	if(*tempstrlist.begin() != "default") tempstrlist.insert(tempstrlist.begin(),QString("default"));
	*downstream << (*codecs = tempstrlist);
	
	tempstrlist = printerlist->getItemList();
	if(*tempstrlist.begin() != "default") tempstrlist.insert(tempstrlist.begin(),QString("default"));
	*downstream << (*printers = tempstrlist);	
	
	// call QDialogs accept() method
	accept();
}
